# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/tester/tester/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/tester/tester/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Tester\\Tester\\": "packages/tester/tester/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Tester\Tester\Providers\TesterServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Tester'  => Tester\Tester\Facades\Tester::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Tester\\TesterTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Tester\Tester\Providers\TesterServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Tester\Tester\Providers\TesterServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Tester\Tester\Providers\TesterServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/tester/{modulename}

**User**

    http://path-to-route-folder/user/tester/{modulename}

**Public**

    http://path-to-route-folder/testers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/tester/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/tester/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/tester/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/tester/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/tester/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/tester/{modulename}/{slug}
    METHOD: GET